<?php
/**
 * @file
 * Zen theme's implementation to display a single Drupal page.
 *
 * Available variables:
 *
 * General utility variables:
 * - $base_path: The base URL path of the Drupal installation. At the very
 *   least, this will always default to /.
 * - $directory: The directory the template is located in, e.g. modules/system
 *   or themes/bartik.
 * - $is_front: TRUE if the current page is the front page.
 * - $logged_in: TRUE if the user is registered and signed in.
 * - $is_admin: TRUE if the user has permission to access administration pages.
 *
 * Site identity:
 * - $front_page: The URL of the front page. Use this instead of $base_path,
 *   when linking to the front page. This includes the language domain or
 *   prefix.
 * - $logo: The path to the logo image, as defined in theme configuration.
 * - $site_name: The name of the site, empty when display has been disabled
 *   in theme settings.
 * - $site_slogan: The slogan of the site, empty when display has been disabled
 *   in theme settings.
 *
 * Navigation:
 * - $main_menu (array): An array containing the Main menu links for the
 *   site, if they have been configured.
 * - $secondary_menu (array): An array containing the Secondary menu links for
 *   the site, if they have been configured.
 * - $secondary_menu_heading: The title of the menu used by the secondary links.
 * - $breadcrumb: The breadcrumb trail for the current page.
 *
 * Page content (in order of occurrence in the default page.tpl.php):
 * - $title_prefix (array): An array containing additional output populated by
 *   modules, intended to be displayed in front of the main title tag that
 *   appears in the template.
 * - $title: The page title, for use in the actual HTML content.
 * - $title_suffix (array): An array containing additional output populated by
 *   modules, intended to be displayed after the main title tag that appears in
 *   the template.
 * - $messages: HTML for status and error messages. Should be displayed
 *   prominently.
 * - $tabs (array): Tabs linking to any sub-pages beneath the current page
 *   (e.g., the view and edit tabs when displaying a node).
 * - $action_links (array): Actions local to the page, such as 'Add menu' on the
 *   menu administration interface.
 * - $feed_icons: A string of all feed icons for the current page.
 * - $node: The node object, if there is an automatically-loaded node
 *   associated with the page, and the node ID is the second argument
 *   in the page's path (e.g. node/12345 and node/12345/revisions, but not
 *   comment/reply/12345).
 *
 * Regions:
 * - $page['header']: Items for the header region.
 * - $page['navigation']: Items for the navigation region, below the main menu (if any).
 * - $page['help']: Dynamic help text, mostly for admin pages.
 * - $page['highlighted']: Items for the highlighted content region.
 * - $page['content']: The main content of the current page.
 * - $page['sidebar_first']: Items for the first sidebar.
 * - $page['sidebar_second']: Items for the second sidebar.
 * - $page['footer']: Items for the footer region.
 * - $page['bottom']: Items to appear at the bottom of the page below the footer.
 *
 * @see template_preprocess()
 * @see template_preprocess_page()
 * @see zen_preprocess_page()
 * @see template_process()
 */
?>
<div id="page_wrapper">
	<div id="top-border" class="wrapper-horizontal"></div>
	<div id="page">
		
	 <?php
      // Render the header to see if there's anything in it.
      $header  = render($page['header']);
    ?>

    <?php if ($header): ?>
	  <header id="header" role="banner">
	      <?php if ($main_menu): ?>
	        <nav id="main-menu" role="navigation">
	          <?php
	          // This code snippet is hard to modify. We recommend turning off the
	          // "Main menu" on your sub-theme's settings form, deleting this PHP
	          // code block, and, instead, using the "Menu block" module.
	          // @see http://drupal.org/project/menu_block
	          print theme('links__system_main_menu', array(
	            'links' => $main_menu,
	            'attributes' => array(
	              'class' => array('links', 'inline', 'clearfix'),
	            ),
	            'heading' => array(
	              'text' => t('Main menu'),
	              'level' => 'h2',
	              'class' => array('element-invisible'),
	            ),
	          )); ?>
	        </nav>
	      <?php endif; ?>
		
	      <?php print render($page['header']); ?>
	
	  </header>
	<?php endif; ?>
	
	  <div id="main">
	  	<!-- Splash image is processed in template.php -->
		<div id="splash">
			<?php if ($variables['splash']) { ?>
				<img src="<?php print $variables['splash']; ?>" />
			<?php } ?>
			<?php if ($site_name || $site_slogan): ?>
		      <hgroup id="name-and-slogan">
		        <?php if ($site_name): ?>
		          <h1 id="site-name">
		            <a href="<?php print $front_page; ?>" title="<?php print t('Home'); ?>" rel="home"><span><?php print $site_name; ?></span></a>
		          </h1>
		        <?php endif; ?>
		        <?php if ($site_slogan): ?>
		          <h2 id="site-slogan"><?php print $site_slogan; ?></h2>
		        <?php endif; ?>
		      </hgroup><!-- /#name-and-slogan -->
		    <?php endif; ?>
		</div>
	    <div id="content" class="column" role="main">
	      <?php print render($page['highlighted']); ?>
	      <?php print $breadcrumb; ?>
	      <a id="main-content"></a>
	      <?php print $messages; ?>
	      <?php print render($tabs); ?>
	      <?php print render($page['help']); ?>
	      <?php if ($action_links): ?>
	        <ul class="action-links"><?php print render($action_links); ?></ul>
	      <?php endif; ?>
	      <?php print render($page['content']); ?>
	      <?php print $feed_icons; ?>
	    </div><!-- /#content -->
	
	  </div><!-- /#main -->

			<div id="footer">
				<div id="footer_title"></div>
				<div id="footer_wrapper">
					<div id="footer1" class="footer_contents"><?php print render($page['footer1']); ?></div>
					<div id="footer2" class="footer_contents"><?php print render($page['footer2']); ?></div>
					<div id="footer3" class="footer_contents"><?php print render($page['footer3']); ?></div>
				</div>
			</div>
			<div id="footer_bottom"></div><!-- /#footer -->
	</div><!-- /#page -->
	<div id="bottom-border" class="wrapper-horizontal"></div>
	<?php print render($page['bottom']); ?>
</div>

